Package: altcdfenvs
Version: 2.74.0
Title: alternative CDF environments (aka probeset mappings)
Author: Laurent Gautier <lgautier@gmail.com>
Maintainer: Laurent Gautier <lgautier@gmail.com>
biocViews: Microarray, OneChannel, QualityControl, Preprocessing,
        Annotation, ProprietaryPlatforms, Transcription
Depends: R (>= 2.7), methods, BiocGenerics (>= 0.1.0), S4Vectors (>=
        0.9.25), Biobase (>= 2.15.1), affy, makecdfenv, Biostrings,
        hypergraph
Suggests: plasmodiumanophelescdf, hgu95acdf, hgu133aprobe, hgu133a.db,
        hgu133acdf, Rgraphviz, RColorBrewer
Description: Convenience data structures and functions to handle
        cdfenvs
License: GPL (>= 2)
Collate: appendCdfEnvAffy.R buildCdfEnv.matchprobes.R
        buildCdfEnv.biostrings.R CdfEnv.R cdfenvs.R copyCdfEnvAffy.R
        readFASTA.R removeIndex.R unique.CdfEnvAffy.R
LazyLoad: yes
Packaged: 2026-04-28 20:34:29 UTC; biocbuild
git_url: https://git.bioconductor.org/packages/altcdfenvs
git_branch: RELEASE_3_23
git_last_commit: d1163ab
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
